# TODO: fix sphinx docs build (sphinx-build hangs?)
#
# Conditional build:
%bcond_without	tests		# unit tests
%bcond_with	apidocs		# Sphinx based HTML documentation [hangs, FIXME]
%bcond_without	static_libs	# static library
%bcond_without	python		# Python bindings
%bcond_without	python2		# CPython 2.x binding
%bcond_without	python3		# CPython 3.x binding

%if %{without python}
%undefine	with_python2
%undefine	with_python3
%endif
Summary:	Crypto library written in C++
Summary(pl.UTF-8):	Biblioteka kryptograficzna napisana w C++
Name:		botan2
Version:	2.7.0
Release:	3
License:	BSD
Group:		Libraries
Source0:	https://botan.randombit.net/releases/Botan-%{version}.tgz
# Source0-md5:	c819fce944ee688e01b07bb6332d9586
URL:		https://botan.randombit.net/
BuildRequires:	bzip2-devel
BuildRequires:	libstdc++-devel
BuildRequires:	openssl-devel
BuildRequires:	python >= 1:2.7
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
%{?with_apidocs:BuildRequires:	sphinx-pdg}
BuildRequires:	zlib-devel
%if %{with python2}
BuildRequires:	python-devel >= 1:2.7
%endif
%if %{with python3}
BuildRequires:	python3-devel >= 1:3.4
%endif
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Botan is a BSD-licensed crypto library written in C++. It provides a
wide variety of basic cryptographic algorithms, X.509 certificates and
CRLs, PKCS#10 certificate requests, a filter/pipe message processing
system, and a wide variety of other features, all written in portable
C++. The API reference, tutorial, and examples may help impart the
flavor of the library.

%description -l pl.UTF-8
Botan to biblioteka kryptograficzna na licencji BSD, napisana w C++.
Zapewnia szeroki zakres algorytmów kryptograficznych, certyfikaty
X.509 oraz CRL, żądania certyfikatów PKCS#10, system przetwarzania
komunikatów z filtrowaniem/potokami i wiele innych funkcji, wszystko
napisane w przenośnym C++. Dodatkowe udogodnienia to dokumentacja API,
wprowadzenie oraz przykłady.

%package devel
Summary:	Header files for Botan library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki Botan
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	bzip2-devel
Requires:	gmp-devel
Requires:	openssl-devel
Requires:	zlib-devel

%description devel
This package contains the header files for developing applications
that use Botan.

%description devel
Ten pakiet zawiera pliki nagłówkowe do tworzenia aplikacji
wykorzystujących bibliotekę Botan.

%package static
Summary:	Static Botan library
Summary(pl.UTF-8):	Statyczna biblioteka Botan
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static Botan library.

%description static -l pl.UTF-8
Statyczna biblioteka Botan.

%package apidocs
Summary:	Botan API documentation
Summary(pl.UTF-8):	Dokumentacja API biblioteki Botan
Group:		Documentation
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description apidocs
API and internal documentation for Botan library.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki Botan.

%package -n python-botan
Summary:	Python 2.x binding for Botan library
Summary(pl.UTF-8):	Wiązanie Pythona 2.x do biblioteki Botan
Group:		Libraries/Python
Requires:	%{name} = %{version}-%{release}

%description -n python-botan
Python 2.x binding for Botan library.

%description -n python-botan -l pl.UTF-8
Wiązanie Pythona 2.x do biblioteki Botan.

%package -n python3-botan
Summary:	Python 3.x binding for Botan library
Summary(pl.UTF-8):	Wiązanie Pythona 3.x do biblioteki Botan
Group:		Libraries/Python
Requires:	%{name} = %{version}-%{release}

%description -n python3-botan
Python 3.x binding for Botan library.

%description -n python3-botan -l pl.UTF-8
Wiązanie Pythona 3.x do biblioteki Botan.

%prep
%setup -q -n Botan-%{version}

# kill shebang, nothing to execute directly
%{__sed} -i -e '1d' src/python/botan2.py

%build
# we have the necessary prerequisites, so enable optional modules
%define enable_modules bzip2,lzma,zlib,openssl,sqlite3,tpm,pkcs11

# fixme: maybe disable unix_procs, very slow.
%define disable_modules %{nil}

./configure.py \
	--prefix=%{_prefix} \
	--libdir=%{_lib} \
	--cc=gcc \
	--os=linux \
	--cpu=%{_arch} \
	--enable-modules=%{enable_modules} \
	--disable-modules=%{disable_modules} \
%if %{with python2}
	--with-python-version=%{py_ver} \
%endif
	%{!?with_apidocs:--without-sphinx}

# (ab)using CXX as an easy way to inject our CXXFLAGS
%{__make} \
	CXX="%{__cxx} -pthread" \
	CXXFLAGS="%{rpmcxxflags}"

%if %{with apidocs}
%{__make} docs
%endif

%if %{with tests}
LD_LIBRARY_PATH=. ./botan-test
%endif

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	INSTALL_CMD_EXEC="install -p -m 755" \
	INSTALL_CMD_DATA="install -p -m 644" \
	DESTDIR=$RPM_BUILD_ROOT

%if %{with python2}
%py_comp $RPM_BUILD_ROOT%{py_sitedir}
%py_ocomp $RPM_BUILD_ROOT%{py_sitedir}
%py_postclean
%endif

%if %{with python3}
install -d $RPM_BUILD_ROOT%{py3_sitedir}
cp -p src/python/botan2.py $RPM_BUILD_ROOT%{py3_sitedir}
%py3_comp $RPM_BUILD_ROOT%{py3_sitedir}
%py3_ocomp $RPM_BUILD_ROOT%{py3_sitedir}
%endif

# packaged as %doc
%{__rm} -r $RPM_BUILD_ROOT%{_docdir}/botan-%{version}

%if %{with apidocs}
install -d $RPM_BUILD_ROOT%{_examplesdir}
cp -pr doc/examples $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc license.txt news.rst readme.rst doc/{authors.txt,credits.rst,reading_list.txt,manual/roadmap.rst,security.rst,todo.rst}
%attr(755,root,root) %{_bindir}/botan
%attr(755,root,root) %{_libdir}/libbotan-2.so.*.*
%attr(755,root,root) %ghost %{_libdir}/libbotan-2.so.7
%{_mandir}/man1/botan.1*

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libbotan-2.so
%{_includedir}/botan-2
%{_pkgconfigdir}/botan-2.pc

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libbotan-2.a
%endif

%if %{with apidocs}
%files apidocs
%defattr(644,root,root,755)
# FIXME: update path after fixing sphinx build
%doc _doc/manual/{_static,*.html,*.js}
%{_examplesdir}/%{name}-%{version}
%endif

%if %{with python2}
%files -n python-botan
%defattr(644,root,root,755)
%{py_sitedir}/botan2.py[co]
%endif

%if %{with python3}
%files -n python3-botan
%defattr(644,root,root,755)
%{py3_sitedir}/botan2.py
%{py3_sitedir}/__pycache__/botan2.cpython-*.py[co]
%endif
%changelog
* Mon Oct 28 2019 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/botan2.git;a=log;h=master

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> 3c6e886
- rebuild with python 3.8
- release 3 (by relup.sh)

* Sat Sep 15 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> bd83560
- release 2 (by relup.sh)

* Wed Sep 12 2018 Adam Osuchowski <adwol@pld-linux.org> d2c937c
- up to 2.7.0

* Sat Jun 30 2018 Jakub Bogusz <qboosh@pld-linux.org> 189a518
- updated to 2.6.0 (as botan2)

* Fri Jun 29 2018 Jakub Bogusz <qboosh@pld-linux.org> ac90ec6
- updated to 1.10.17 (latests 1.x version; new soname)
- removed obsolete soname patch
- added includes patch (fix missing stdint include)
- added python patch (allow multiple pythons build)

* Wed Mar 01 2017 Jakub Bogusz <qboosh@pld-linux.org> 93e6aed
- pl, cleanup

* Thu Apr 03 2014 Elan Ruusamäe <glen@delfi.ee> fed2778
- noarch apidocs

* Thu Feb 21 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> f7749ed
- rel 2; drop botan-config, force pkg-config usage

* Thu Feb 21 2013 Arkadiusz Miśkiewicz <arekm@maven.pl> 6f95543
- up to 1.8.14

* Thu Sep 01 2011 Elan Ruusamäe <glen@pld-linux.org> 923e008
- still call ldconfig for cache updating

* Thu Sep 01 2011 Elan Ruusamäe <glen@pld-linux.org> 7f5657d
- new, based on fedora package

